@@ -97,7 +97,7 @@ std::vector<std::string> parseList(const std::string &s, const std::string &sep
 void parse_ProgramOptions_sort(int argc, char **argv, Bustools_opt &opt)
 {
   
-  const char *opt_string = "t:o:m:T:cusp";
+  const char *opt_string = "t:o:m:T:cuspn";
   
   static struct option long_options[] = {
     {"threads", required_argument, 0, 't'},
@@ -105,6 +105,7 @@ void parse_ProgramOptions_sort(int argc, char **argv, Bustools_opt &opt)
     {"memory", required_argument, 0, 'm'},
     {"temp", required_argument, 0, 'T'},
     {"umi", no_argument, 0, 'u'},
+    {"no-flags", no_argument, 0, 'n'},
     {"count", no_argument, 0, 'c'},
     {"flags", no_argument, 0, 'F'},
     {"flags-bc", no_argument, 0, 'f'},
@@ -127,6 +128,9 @@ void parse_ProgramOptions_sort(int argc, char **argv, Bustools_opt &opt)
     case 'o':
       opt.output = optarg;
       break;
+    case 'n':
+      opt.sort_noflag = true; // Not implemented (ideally, would want to have this remove the flag column while sorting)
+      break;
     case 'm':
       s = optarg;
       sh = 0;
@@ -172,6 +176,9 @@ void parse_ProgramOptions_sort(int argc, char **argv, Bustools_opt &opt)
     case 'p':
       opt.stream_out = true;
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
@@ -213,6 +220,9 @@ void parse_ProgramOptions_merge(int argc, char **argv, Bustools_opt &opt)
     case 'e':
       opt.count_ecs = optarg;
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
@@ -245,6 +255,9 @@ void parse_ProgramOptions_mash(int argc, char **argv, Bustools_opt &opt)
     case 'o':
       opt.output = optarg;
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
@@ -312,6 +325,9 @@ void parse_ProgramOptions_capture(int argc, char **argv, Bustools_opt &opt)
     case 'p':
       opt.stream_out = true;
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
@@ -328,7 +344,7 @@ void parse_ProgramOptions_capture(int argc, char **argv, Bustools_opt &opt)
 
 void parse_ProgramOptions_count(int argc, char **argv, Bustools_opt &opt)
 {
-  const char *opt_string = "o:g:e:t:md:";
+  const char *opt_string = "o:g:e:t:md:s:";
   int gene_flag = 0;
   int umigene_flag = 0;
   int em_flag = 0;
@@ -348,6 +364,7 @@ void parse_ProgramOptions_count(int argc, char **argv, Bustools_opt &opt)
     {"hist", no_argument, &hist_flag, 1},
     {"downsample", required_argument, 0, 'd'},
     {"rawcounts", no_argument, &rawcounts_flag, 1},
+    {"split", required_argument, 0, 's'},
     {0, 0, 0, 0}};
   
   int option_index = 0, c;
@@ -375,24 +392,26 @@ void parse_ProgramOptions_count(int argc, char **argv, Bustools_opt &opt)
     case 'm':
       opt.count_gene_multimapping = true;
       break;
+    case 's':
+      opt.count_split = optarg;
+      break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
   }
-  if (gene_flag)
-  {
+  if (gene_flag) {
     opt.count_collapse = true;
   }
-  if (umigene_flag)
-  {
+  if (umigene_flag) {
     opt.umi_gene_collapse = true;
   }
-  if (em_flag)
-  {
+  if (em_flag) {
     opt.count_em = true;
   }
-  if (cm_flag)
-  {
+  if (cm_flag) {
     opt.count_cm = true;
   }
   if (hist_flag) {
@@ -446,6 +465,9 @@ void parse_ProgramOptions_umicorrect(int argc, char **argv, Bustools_opt& opt) {
     case 'e':
       opt.count_ecs = optarg;
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
@@ -480,6 +502,9 @@ void parse_ProgramOptions_predict(int argc, char **argv, Bustools_opt& opt) {
     case 't':
       opt.predict_t = atof(optarg);
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
@@ -493,13 +518,14 @@ void parse_ProgramOptions_predict(int argc, char **argv, Bustools_opt& opt) {
 void parse_ProgramOptions_dump(int argc, char **argv, Bustools_opt &opt)
 {
   
-  const char *opt_string = "o:pfd";
+  const char *opt_string = "o:pfda";
   
   static struct option long_options[] = {
     {"output", required_argument, 0, 'o'},
     {"pipe", no_argument, 0, 'p'},
     {"flags", no_argument, 0, 'f'},
     {"pad", no_argument, 0, 'd'},
+    {"showAll", no_argument, 0, 'a'},
     {0, 0, 0, 0}};
   
   int option_index = 0, c;
@@ -521,6 +547,12 @@ void parse_ProgramOptions_dump(int argc, char **argv, Bustools_opt &opt)
     case 'd':
       opt.text_dumppad = true;
       break;
+    case 'a':
+      opt.text_showall = true;
+      break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
@@ -560,6 +592,9 @@ void parse_ProgramOptions_fromtext(int argc, char **argv, Bustools_opt& opt) {
     case 'p':
       opt.stream_out = true;
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
@@ -576,13 +611,15 @@ void parse_ProgramOptions_fromtext(int argc, char **argv, Bustools_opt& opt) {
 void parse_ProgramOptions_correct(int argc, char **argv, Bustools_opt &opt)
 {
   
-  const char *opt_string = "o:w:d:sp";
+  const char *opt_string = "o:w:d:spr";
   static struct option long_options[] = {
     {"output", required_argument, 0, 'o'},
     {"whitelist", required_argument, 0, 'w'},
+    {"onlist", required_argument, 0, 'w'},
     {"dump", required_argument, 0, 'd'},
     {"split", no_argument, 0, 's'},
     {"pipe", no_argument, 0, 'p'},
+    {"replace", no_argument, 0, 'r'},
     {0, 0, 0, 0}};
   
   int option_index = 0, c;
@@ -608,6 +645,12 @@ void parse_ProgramOptions_correct(int argc, char **argv, Bustools_opt &opt)
     case 'p':
       opt.stream_out = true;
       break;
+    case 'r':
+      opt.barcode_replacement = true;
+      break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
@@ -650,12 +693,15 @@ void parse_ProgramOptions_whitelist(int argc, char **argv, Bustools_opt &opt)
     case 'f':
       opt.threshold = atoi(optarg);
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
   }
   
-  /* All other argumuments are (sorted) BUS files. */
+  /* All other arguments are (sorted) BUS files. */
   while (optind < argc)
     opt.files.push_back(argv[optind++]);
   
@@ -717,12 +763,15 @@ void parse_ProgramOptions_project(int argc, char **argv, Bustools_opt &opt)
     case 'p':
       opt.stream_out = true;
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
   }
   
-  /* All other argumuments are (sorted) BUS files. */
+  /* All other arguments are (sorted) BUS files. */
   while (optind < argc)
     opt.files.push_back(argv[optind++]);
   
@@ -742,6 +791,7 @@ void parse_ProgramOptions_inspect(int argc, char **argv, Bustools_opt &opt)
     {"output", required_argument, 0, 'o'},
     {"ecmap", required_argument, 0, 'e'},
     {"whitelist", required_argument, 0, 'w'},
+    {"onlist", required_argument, 0, 'w'},
     {"pipe", no_argument, 0, 'p'},
     {0, 0, 0, 0}};
   
@@ -763,12 +813,15 @@ void parse_ProgramOptions_inspect(int argc, char **argv, Bustools_opt &opt)
     case 'p':
       opt.stream_out = true;
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
   }
   
-  /* All other argumuments are (sorted) BUS files. */
+  /* All other arguments are (sorted) BUS files. */
   while (optind < argc)
     opt.files.push_back(argv[optind++]);
   
@@ -809,12 +862,15 @@ void parse_ProgramOptions_linker(int argc, char **argv, Bustools_opt &opt)
     case 'p':
       opt.stream_out = true;
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
   }
   
-  /* All other argumuments are (sorted) BUS files. */
+  /* All other arguments are (sorted) BUS files. */
   while (optind < argc)
     opt.files.push_back(argv[optind++]);
   
@@ -856,6 +912,9 @@ void parse_ProgramOptions_collapse(int argc, char** argv, Bustools_opt& opt) {
     case 'e':
       opt.count_ecs = optarg;
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
@@ -904,6 +963,9 @@ void parse_ProgramOptions_clusterhist(int argc, char** argv, Bustools_opt& opt)
     case 'c':
       opt.cluster_input_file = optarg;
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
@@ -947,12 +1009,15 @@ void parse_ProgramOptions_extract(int argc, char **argv, Bustools_opt &opt)
     case 'p':
       opt.stream_out = true;
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
   }
   
-  /* All other argumuments are (sorted) BUS files. */
+  /* All other arguments are (sorted) BUS files. */
   while (optind < argc)
     opt.files.push_back(argv[optind++]);
   
@@ -994,6 +1059,9 @@ bool parse_ProgramOptions_inflate(int argc, char **argv, Bustools_opt &opt)
     case 'h':
       print_usage = true;
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
@@ -1074,6 +1142,9 @@ bool parse_ProgramOptions_compress(int argc, char **argv, Bustools_opt &opt)
     case 'h':
       print_usage = true;
       break;
+    case '?':
+      opt.parse_error = true;
+      break;
     default:
       break;
     }
@@ -1093,7 +1164,11 @@ bool check_ProgramOptions_sort(Bustools_opt &opt)
 {
   
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   size_t max_threads = std::thread::hardware_concurrency();
   
   if (opt.threads <= 0)
@@ -1220,7 +1295,11 @@ bool check_ProgramOptions_sort(Bustools_opt &opt)
 bool check_ProgramOptions_merge(Bustools_opt &opt)
 {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   // check for output directory
   if (!opt.stream_out)
   {
@@ -1309,7 +1388,11 @@ bool check_ProgramOptions_merge(Bustools_opt &opt)
 bool check_ProgramOptions_mash(Bustools_opt &opt)
 {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   if (opt.output.empty())
   {
     std::cerr << "Error: missing output directory" << std::endl;
@@ -1378,7 +1461,11 @@ bool check_ProgramOptions_mash(Bustools_opt &opt)
 bool check_ProgramOptions_dump(Bustools_opt &opt)
 {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   if (!opt.stream_out)
   {
     if (opt.output.empty())
@@ -1416,7 +1503,11 @@ bool check_ProgramOptions_dump(Bustools_opt &opt)
 bool check_ProgramOptions_fromtext(Bustools_opt& opt) 
 {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   if (!opt.stream_out) 
   {
     if (opt.output.empty()) 
@@ -1455,7 +1546,11 @@ bool check_ProgramOptions_fromtext(Bustools_opt& opt)
 bool check_ProgramOptions_capture(Bustools_opt &opt)
 {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   if (opt.filter)
   {
     // check if output directory exists or if we can create it
@@ -1567,7 +1662,11 @@ bool check_ProgramOptions_capture(Bustools_opt &opt)
 bool check_ProgramOptions_correct(Bustools_opt &opt)
 {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   if (!opt.stream_out)
   {
     if (opt.output.empty())
@@ -1604,7 +1703,7 @@ bool check_ProgramOptions_correct(Bustools_opt &opt)
   
   if (opt.whitelist.size() == 0)
   {
-    std::cerr << "Error: Missing whitelist file" << std::endl;
+    std::cerr << "Error: Missing on-list file" << std::endl;
     ret = false;
   }
   else
@@ -1630,97 +1729,81 @@ bool check_ProgramOptions_correct(Bustools_opt &opt)
 bool check_ProgramOptions_count(Bustools_opt &opt)
 {
   bool ret = true;
+
+  if (opt.parse_error) {
+      ret = false;
+  }
   
   // check for output directory
-  if (opt.output.empty())
-  {
+  if (opt.output.empty()) {
     std::cerr << "Error: Missing output directory" << std::endl;
     ret = false;
   }
-  else
-  {
+  else {
     bool isDir = false;
-    if (checkDirectoryExists(opt.output))
-    {
+    if (checkDirectoryExists(opt.output)) {
       isDir = true;
     }
-    else
-    {
-      if (opt.output.at(opt.output.size() - 1) == '/')
-      {
-        if (my_mkdir(opt.output.c_str(), 0777) == -1)
-        {
+    else {
+      if (opt.output.at(opt.output.size() - 1) == '/') {
+        if (my_mkdir(opt.output.c_str(), 0777) == -1) {
           std::cerr << "Error: could not create directory " << opt.output << std::endl;
           ret = false;
         }
-        else
-        {
+        else {
           isDir = true;
         }
       }
     }
     
-    if (isDir)
-    {
+    if (isDir) {
       opt.output += "output";
     }
   }
   
-  if (opt.count_em && opt.count_gene_multimapping)
-  {
+  if (opt.count_em && opt.count_gene_multimapping) {
     std::cerr << "Error: EM algorithm and counting multimapping reads are incompatible" << std::endl;
     ret = false;
   }
   
-  if (opt.count_em && opt.count_cm)
-  {
+  if (opt.count_em && opt.count_cm) {
     std::cerr << "Error: EM algorithm and counting multiplicites are incompatible" << std::endl;
     ret = false;
   }
   
-  if (opt.umi_gene_collapse && opt.count_cm)
-  {
+  if (opt.umi_gene_collapse && opt.count_cm) {
     std::cerr << "Error: Gene-level collapsing of UMIs and counting multiplicites are incompatible" << std::endl;
     ret = false;
   }
   
-  if (opt.umi_gene_collapse && (opt.count_raw_counts || opt.count_gen_hist || opt.count_downsampling_factor != 1.0))
-  {
+  if (opt.umi_gene_collapse && (opt.count_raw_counts || opt.count_gen_hist || opt.count_downsampling_factor != 1.0)) {
     std::cerr << "Error: Gene-level collapsing of UMIs is currently incompatible with --hist, --downsample, or --rawcounts" << std::endl;
     ret = false;
   }
   
-  if (opt.count_cm && (opt.count_raw_counts || opt.count_gen_hist || opt.count_downsampling_factor != 1.0))
-  {
+  if (opt.count_cm && (opt.count_raw_counts || opt.count_gen_hist || opt.count_downsampling_factor != 1.0)) {
     std::cerr << "Error: Counting multiplicites is incompatible with --hist, --downsample, or --rawcounts" << std::endl;
     ret = false;
   }
   
-  if (opt.count_raw_counts && opt.count_em) 
-  {
+  if (opt.count_raw_counts && opt.count_em)  {
     std::cerr << "Error: Counting raw counts are not supported for the EM algorithm" << std::endl;
     ret = false;
   }
   
-  if (opt.count_raw_counts && !opt.count_collapse) 
-  {
+  if (opt.count_raw_counts && !opt.count_collapse)  {
     std::cerr << "Error: Raw counts are currently only supported for gene counting, not ec counting." << std::endl;
     ret = false;
   }
   
-  if (opt.files.size() == 0)
-  {
+  if (opt.files.size() == 0) {
     std::cerr << "Error: Missing BUS input files" << std::endl;
     ret = false;
   }
-  else
-  {
-    if (!opt.stream_in)
-    {
-      for (const auto &it : opt.files)
-      {
-        if (!checkFileExists(it))
-        {
+  else {
+    if (!opt.stream_in) {
+      for (const auto &it : opt.files) {
+        if (!checkFileExists(it)) {
           std::cerr << "Error: File not found, " << it << std::endl;
           ret = false;
         }
@@ -1728,13 +1811,11 @@ bool check_ProgramOptions_count(Bustools_opt &opt)
     }
   }
   
-  if (opt.count_genes.size() == 0)
-  {
+  if (opt.count_genes.size() == 0) {
     std::cerr << "Error: missing gene mapping file" << std::endl;
     ret = false;
   }
-  else
-  {
+  else {
     if (!checkFileExists(opt.count_genes))
     {
       std::cerr << "Error: File not found " << opt.count_genes << std::endl;
@@ -1742,13 +1823,11 @@ bool check_ProgramOptions_count(Bustools_opt &opt)
     }
   }
   
-  if (opt.count_ecs.size() == 0)
-  {
+  if (opt.count_ecs.size() == 0) {
     std::cerr << "Error: missing equivalence class mapping file" << std::endl;
     ret = false;
   }
-  else
-  {
+  else {
     if (!checkFileExists(opt.count_ecs))
     {
       std::cerr << "Error: File not found " << opt.count_ecs << std::endl;
@@ -1756,26 +1835,38 @@ bool check_ProgramOptions_count(Bustools_opt &opt)
     }
   }
   
-  if (opt.count_txp.size() == 0)
-  {
+  if (opt.count_txp.size() == 0) {
     std::cerr << "Error: missing transcript name file" << std::endl;
     ret = false;
   }
-  else
-  {
-    if (!checkFileExists(opt.count_txp))
-    {
+  else {
+    if (!checkFileExists(opt.count_txp)) {
       std::cerr << "Error: File not found " << opt.count_txp << std::endl;
       ret = false;
     }
   }
   
+  if (opt.count_split.size() != 0) {
+    if (!checkFileExists(opt.count_split)) {
+      std::cerr << "Error: File not found " << opt.count_split << std::endl;
+      ret = false;
+    }
+    if (opt.count_em) {
+      std::cerr << "Cannot use -s with --em" << std::endl;
+      ret = false;
+    }
+  }
+  
   return ret;
 }
 
 bool check_ProgramOptions_predict(Bustools_opt& opt) {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   // check for output directory
   if (opt.output.empty()) {
     std::cerr << "Error: Missing output directory" << std::endl;
@@ -1846,7 +1937,11 @@ bool check_ProgramOptions_predict(Bustools_opt& opt) {
 
 bool check_ProgramOptions_umicorrect(Bustools_opt& opt) {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   if (!opt.stream_out) {
     if (opt.output.empty()) {
       std::cerr << "Error: missing output file" << std::endl;
@@ -1907,7 +2002,11 @@ bool check_ProgramOptions_umicorrect(Bustools_opt& opt) {
 bool check_ProgramOptions_whitelist(Bustools_opt &opt)
 {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   if (opt.output.empty())
   {
     std::cerr << "Error: missing output file" << std::endl;
@@ -1956,7 +2055,11 @@ bool check_ProgramOptions_whitelist(Bustools_opt &opt)
 bool check_ProgramOptions_project(Bustools_opt &opt)
 {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   if (opt.output.empty())
   {
     std::cerr << "Error: Missing output file" << std::endl;
@@ -2068,7 +2171,11 @@ bool check_ProgramOptions_project(Bustools_opt &opt)
 bool check_ProgramOptions_inspect(Bustools_opt &opt)
 {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   if (opt.output.size() && !checkOutputFileValid(opt.output))
   {
     std::cerr << "Error: unable to open output file" << std::endl;
@@ -2124,7 +2231,11 @@ bool check_ProgramOptions_inspect(Bustools_opt &opt)
 bool check_ProgramOptions_linker(Bustools_opt &opt)
 {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   if (!opt.stream_out)
   {
     if (opt.output.empty())
@@ -2164,7 +2275,11 @@ bool check_ProgramOptions_linker(Bustools_opt &opt)
 
 bool check_ProgramOptions_collapse(Bustools_opt& opt) {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   // check for output directory
   if (opt.output.empty()) {
     std::cerr << "Error: Missing output directory" << std::endl;
@@ -2245,7 +2360,11 @@ bool check_ProgramOptions_collapse(Bustools_opt& opt) {
 
 bool check_ProgramOptions_clusterhist(Bustools_opt& opt) {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   // check for output directory
   if (opt.output.empty()) {
     std::cerr << "Error: Missing output directory" << std::endl;
@@ -2343,7 +2462,11 @@ bool check_ProgramOptions_clusterhist(Bustools_opt& opt) {
 bool check_ProgramOptions_extract(Bustools_opt &opt)
 {
   bool ret = true;
-  
+
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   if (opt.output.empty())
   {
     std::cerr << "Error: missing output directory" << std::endl;
@@ -2434,9 +2557,12 @@ bool check_ProgramOptions_extract(Bustools_opt &opt)
 
 bool check_ProgramOptions_inflate(Bustools_opt &opt)
 {
-
   bool ret = true;
 
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   if (!opt.stream_out)
   {
     if (opt.output.empty())
@@ -2479,6 +2605,10 @@ bool check_ProgramOptions_compress(Bustools_opt &opt)
 {
   bool ret = true;
 
+  if (opt.parse_error) {
+    ret = false;
+  }
+
   if (!opt.stream_out)
   {
     if (opt.output.empty())
@@ -2530,18 +2660,19 @@ void Bustools_Usage()
             << "umicorrect      Error correct the UMIs in a BUS file" << std::endl
             << "count           Generate count matrices from a BUS file" << std::endl
             << "inspect         Produce a report summarizing a BUS file" << std::endl
-            << "whitelist       Generate a whitelist from a BUS file" << std::endl
-            << "project         Project a BUS file to gene sets" << std::endl
+            << "allowlist       Generate an on-list from a BUS file" << std::endl
+            //<< "project         Project a BUS file to gene sets" << std::endl
             << "capture         Capture records from a BUS file" << std::endl
-            << "merge           Merge bus files from same experiment" << std::endl
+            //<< "merge           Merge bus files from same experiment" << std::endl
             << "text            Convert a binary BUS file to a tab-delimited text file" << std::endl
+            << "fromtext        Convert a tab-delimited text file to a binary BUS file" << std::endl
             << "extract         Extract FASTQ reads correspnding to reads in BUS file" << std::endl
-            << "predict         Correct the count matrix using prediction of unseen species" << std::endl
-            << "collapse        Turn BUS files into a BUG file" << std::endl
-            << "clusterhist     Create UMI histograms per cluster" << std::endl
-            << "linker          Remove section of barcodes in BUS files" << std::endl
+            //<< "predict         Correct the count matrix using prediction of unseen species" << std::endl
+            //<< "collapse        Turn BUS files into a BUG file" << std::endl
+            //<< "clusterhist     Create UMI histograms per cluster" << std::endl
+            //<< "linker          Remove section of barcodes in BUS files" << std::endl
             << "compress        Compress a BUS file" << std::endl
-            << "inflate         Decompress a BUSZ (compressed BUS) file" << std::endl
+            << "decompress      Decompress a BUSZ (compressed BUS) file" << std::endl
             << "version         Prints version number" << std::endl
             << "cite            Prints citation information" << std::endl
             << std::endl
@@ -2555,7 +2686,7 @@ void Bustools_sort_Usage()
   std::cout << "Usage: bustools sort [options] bus-files" << std::endl
             << std::endl
             << "Options: " << std::endl
-            << "Default behavior (with no flag) is to sort by barcode, UMI, ec, then flag" << std::endl
+            << "Default behavior is to sort by barcode, UMI, ec, then flag" << std::endl
             << "-t, --threads         Number of threads to use" << std::endl
             << "-m, --memory          Maximum memory used" << std::endl
             << "-T, --temp            Location and prefix for temporary files " << std::endl
@@ -2566,6 +2697,7 @@ void Bustools_sort_Usage()
             << "    --count           Sort by multiplicity, barcode, UMI, then ec" << std::endl
             << "    --flags           Sort by flag, ec, barcode, then UMI" << std::endl
             << "    --flags-bc        Sort by flag, barcode, UMI, then ec" << std::endl
+            << "    --no-flags        Ignore and reset the flag while sorting" << std::endl
             << std::endl;
 }
 
@@ -2619,6 +2751,7 @@ void Bustools_dump_Usage()
             << "-f, --flags           Write the flag column" << std::endl
             << "-d, --pad             Write the pad column" << std::endl
             << "-p, --pipe            Write to standard output" << std::endl
+            << "-a, --showAll         Show hidden metadata in barcodes" << std::endl
             << std::endl;
 }
 
@@ -2637,10 +2770,10 @@ void Bustools_correct_Usage()
             << std::endl
             << "Options: " << std::endl
             << "-o, --output          File for corrected bus output" << std::endl
-            << "-w, --whitelist       File of whitelisted barcodes to correct to" << std::endl
+            << "-w, --onlist          File of on-list barcodes to correct to" << std::endl
             << "-p, --pipe            Write to standard output" << std::endl
             << "-d, --dump            Dump uncorrected to corrected barcodes (optional)" << std::endl
-            << "-s, --split           Split the whitelist and correct each half independently (optional)" << std::endl
+            << "-r, --replace         The file of on-list barcodes is a barcode replacement file" << std::endl
             << std::endl;
 }
 
@@ -2655,12 +2788,13 @@ void Bustools_count_Usage()
             << "-t, --txnames         File with names of transcripts" << std::endl
             << "    --genecounts      Aggregate counts to genes only" << std::endl
             << "    --umi-gene        Perform gene-level collapsing of UMIs" << std::endl
-            << "    --em              Estimate gene abundances using EM algorithm" << std::endl
-            << "    --cm              Count multiplicites instead of UMIs" << std::endl
+            //<< "    --em              Estimate gene abundances using EM algorithm" << std::endl
+            << "    --cm              Count multiplicities instead of UMIs" << std::endl
+            << "-s, --split           Split output matrix in two (plus ambiguous) based on transcripts supplied in this file" << std::endl
             << "-m, --multimapping    Include bus records that pseudoalign to multiple genes" << std::endl
-            << "    --hist            Output copy per UMI histograms for all genes" << std::endl 
-            << "-d  --downsample      Specify a factor between 0 and 1 specifying how much to downsample" << std::endl 
-            << "    --rawcounts       The count matrix will contain raw counts instead of UMI counts" << std::endl 
+            //<< "    --hist            Output copy per UMI histograms for all genes" << std::endl 
+            //<< "-d  --downsample      Specify a factor between 0 and 1 specifying how much to downsample" << std::endl 
+            //<< "    --rawcounts       The count matrix will contain raw counts instead of UMI counts" << std::endl 
             << std::endl;
 }
 
@@ -2686,11 +2820,11 @@ void Bustools_umicorrect_Usage()
 
 void Bustools_whitelist_Usage()
 {
-  std::cout << "Usage: bustools whitelist [options] sorted-bus-file" << std::endl
+  std::cout << "Usage: bustools allowlist [options] sorted-bus-file" << std::endl
             << std::endl
             << "Options: " << std::endl
-            << "-o, --output        File for the whitelist" << std::endl
-            << "-f, --threshold     Minimum number of times a barcode must appear to be included in whitelist" << std::endl
+            << "-o, --output        File for the on-list" << std::endl
+            << "-f, --threshold     Minimum number of times a barcode must appear to be included in on-list" << std::endl
             << std::endl;
 }
 
@@ -2719,7 +2853,7 @@ void Bustools_inspect_Usage()
             << "Options: " << std::endl
             << "-o, --output          File for JSON output (optional)" << std::endl
             << "-e, --ecmap           File for mapping equivalence classes to transcripts" << std::endl
-            << "-w, --whitelist       File of whitelisted barcodes to correct to" << std::endl
+            << "-w, --onlist          File of on-list barcodes to correct to" << std::endl
             << "-p, --pipe            Write to standard output" << std::endl
             << std::endl;
 }
@@ -3031,7 +3165,7 @@ int main(int argc, char **argv)
         exit(1);
       }
     }
-    else if (cmd == "whitelist")
+    else if (cmd == "whitelist" || cmd == "allowlist" || cmd == "onlist")
     {
       if (disp_help)
       {
